Performs the two-sample Ansari–Bradley test (Ansari & Bradley, 1960 https://www.jstor.org/stable/2237814) for univariate, distinct data in the presence of missing values, as described in Zeng et al. (2025) tools:::Rd_expr_doi("10.48550/arXiv.2509.20332"). This method does not make any assumptions about the missingness mechanisms and controls the Type I error regardless of the missing values by taking all possible missing values into account.
Maintainer: Yijin Zeng yijinzeng98@gmail.com